=======================================================
Mazebox
=======================================================
.. image:: https://badge.fury.io/py/mazebox.svg
    :target: https://pypi.org/project/mazebox/
    :alt: Latest PYPi Version

Mazebox is a suite of tools for analyzing single-cell transcriptomics data.


Installation
~~~~~~~~~~~~~~~~~

To install ``Mazebox``, please use::

    pip install mazebox

Dependencies
---------------------

The ``dropkick`` python package will need to be installed, as seen `here <https://github.com/KenLauLab/dropkick>`_.
The ``graph-tool`` python package will need to be installed. This can be installed with `Conda`, `homebrew`, etc as seen on graph-tool's `website <https://git.skewed.de/count0/graph-tool/-/wikis/installation-instructions>`_. 

All other dependencies will be installed with this package.


Mazebox Usage:
~~~~~~~~~~~~~~~~~~~~~~~~
